@@ -1,7 +1,7 @@
 from __future__ import print_function
 import numpy as np
 
-digital_channel_names=['ID1','ID2','ID3','ID4','SEN']
+digital_channel_names=['ID1','ID2','ID3','ID4','SEN','EXT','CNTR']
 
 class digital_channel:
 	EVERY_SIXTEENTH_RISING_EDGE = 5
@@ -48,8 +48,8 @@ class digital_channel:
 		else: self.maxT=0
 
 	def generate_axes(self):
-		HIGH = (4-self.channel_number)*(3)
-		LOW = HIGH - 2.5
+		HIGH = 1#(4-self.channel_number)*(3)
+		LOW = 0#HIGH - 2.5
 		state = HIGH if self.initial_state else LOW
 
 
